@@ -3,15 +3,17 @@ require 'spec_helper'
 describe 'postgresql::globals', :type => :class do
   let :facts do
     {
-      :osfamily => 'Debian',
-      :operatingsystem => 'Debian',
+      :osfamily               => 'Debian',
+      :operatingsystem        => 'Debian',
       :operatingsystemrelease => '6.0',
+      :lsbdistid              => 'Debian',
+      :lsbdistcodename        => 'squeeze',
     }
   end
 
   describe 'with no parameters' do
     it 'should work' do
-      should include_class("postgresql::globals")
+      is_expected.to contain_class("postgresql::globals")
     end
   end
 
@@ -22,7 +24,7 @@ describe 'postgresql::globals', :type => :class do
       }
     end
     it 'should pull in class postgresql::repo' do
-      should include_class("postgresql::repo")
+      is_expected.to contain_class("postgresql::repo")
     end
   end
 end
